@@ -28,24 +28,27 @@ def get_db_info():
     db_info = {
         # https://doi.org/10.6084/m9.figshare.6815705
         "dft_2d": [
-            "https://ndownloader.figshare.com/files/26808917",
-            "d2-3-12-2021.json",
+            "https://ndownloader.figshare.com/files/38521268",
+            "d2-12-12-2022.json",
             "Obtaining 2D dataset 1.1k ...",
-            "https://www.nature.com/articles/s41524-020-00440-1",
+            "https://www.nature.com/articles/s41524-020-00440-1"
+            + "\nOther versions:https://doi.org/10.6084/m9.figshare.6815705",
         ],
         # https://doi.org/10.6084/m9.figshare.6815699
         "dft_3d": [
-            "https://ndownloader.figshare.com/files/29204826",
-            "jdft_3d-8-18-2021.json",
-            "Obtaining 3D dataset 55k ...",
-            "https://www.nature.com/articles/s41524-020-00440-1",
+            "https://ndownloader.figshare.com/files/38521619",
+            "jdft_3d-12-12-2022.json",
+            "Obtaining 3D dataset 76k ...",
+            "https://www.nature.com/articles/s41524-020-00440-1"
+            + "\nOther versions:https://doi.org/10.6084/m9.figshare.6815699",
         ],
         # https://doi.org/10.6084/m9.figshare.6815699
         "cfid_3d": [
             "https://ndownloader.figshare.com/files/29205201",
             "cfid_3d-8-18-2021.json",
             "Obtaining 3D dataset 55k ...",
-            "https://www.nature.com/articles/s41524-020-00440-1",
+            "https://www.nature.com/articles/s41524-020-00440-1"
+            + "\nOther versions:https://doi.org/10.6084/m9.figshare.6815699",
         ],
         # https://doi.org/10.6084/m9.figshare.14213522
         "jff": [
@@ -56,6 +59,14 @@ def get_db_info():
             "Obtaining JARVIS-FF 2k ...",
             "https://www.nature.com/articles/s41524-020-00440-1",
         ],
+        # https://doi.org/10.6084/m9.figshare.21667874
+        "alignn_ff_db": [
+            "https://ndownloader.figshare.com/files/38522315",
+            # "https://ndownloader.figshare.com/files/26809760",
+            "id_prop.json",
+            "Obtaining ALIGNN-FF training DB 300k ...",
+            "https://arxiv.org/abs/2209.05554",
+        ],
         "mp_3d_2020": [
             "https://ndownloader.figshare.com/files/26791259",
             "all_mp.json",
@@ -152,7 +163,7 @@ def get_db_info():
             "https://ndownloader.figshare.com/files/29070555",
             "jqe_tb_folder.json",
             "Obtaining QETB dataset 860k...",
-            "https://www.nature.com/articles/s41524-020-00440-1",
+            "https://arxiv.org/abs/2112.11585",
         ],
         # https://doi.org/10.6084/m9.figshare.14812050
         "omdb": [
@@ -163,16 +174,16 @@ def get_db_info():
         ],
         # https://doi.org/10.6084/m9.figshare.14812044
         "qmof": [
-            "https://ndownloader.figshare.com/files/28501740",
+            "https://figshare.com/ndownloader/files/30972640",
             "qmof_db.json",
-            "Obtaining QMOF dataset 18k...",
+            "Obtaining QMOF dataset 20k...",
             "https://www.cell.com/matter/fulltext/S2590-2385(21)00070-9",
         ],
         # https://doi.org/10.6084/m9.figshare.15127758
         "hmof": [
-            "https://ndownloader.figshare.com/files/29070516",
-            "hmof_db_7_27_2021.json",
-            "Obtaining QMOF dataset 137k...",
+            "https://figshare.com/ndownloader/files/30972655",
+            "hmof_db_9_18_2021.json",
+            "Obtaining hMOF dataset 137k...",
             "https://doi.org/10.1021/acs.jpcc.6b08729",
         ],
         # https://figshare.com/account/projects/100325/articles/14960157
@@ -203,6 +214,13 @@ def get_db_info():
             "Obtaining PDBBind dataset 11k...",
             "https://doi.org/10.1093/bioinformatics/btu626",
         ],
+        # https://doi.org/10.6084/m9.figshare.21713885
+        "snumat": [
+            "https://ndownloader.figshare.com/files/38521736",
+            "snumat.json",
+            "Obtaining SNUMAT Hybrid functional dataset 10k...",
+            "https://www.nature.com/articles/s41597-020-00723-8",
+        ],
         # https://doi.org/10.6084/m9.figshare.13215308
         "aflow2": [
             "https://ndownloader.figshare.com/files/25453265",
