@@ -29,6 +29,7 @@ def test_th_stm():
     t1 = TH_STM1.constant_height()
     TH_STM2 = TersoffHamannSTM(chg_name=name, min_size=5)
     t2 = TH_STM2.constant_current()
+    t2 = TH_STM2.constant_current( use_interpolated=False)
     t2 = TH_STM2.constant_current(pc=5)
     from jarvis.db.figshare import make_stm_from_prev_parchg
 
@@ -37,6 +38,11 @@ def test_th_stm():
     im = Image.crop_from_center()
     ims = Image.augment_image()
 
+    TH_STM1 = TersoffHamannSTM(chg_name=name, min_size=5,use_interpolated=False)
+    t1 = TH_STM1.constant_height(filename="test.png")
+    TH_STM1 = TersoffHamannSTM(chg_name=name, min_size=5, crop_from_center=True)
+    t1 = TH_STM1.constant_height(filename="test.png")
+    t2 = TH_STM1.constant_current( )
     cmd = "rm *.png"
     os.system(cmd)
 
